/*******************************************************************************
* KDE plasma applet to display network interface status.
*
* Copyright (C) 2012 by Eugene Grigorjev <osmiy.lv@gmail.com>
*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 2 of the License, or
* (at your option) any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with this program; if not, write to the Free Software
* Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*******************************************************************************/

// Here we avoid loading the header multiple times
#ifndef NETWORK_STATUS_HEADER
#define NETWORK_STATUS_HEADER

#include <linux/types.h>    /* required for wireless.h */
#include <sys/socket.h>     /* required for wireless.h */
#include <net/if.h>         /* required for wireless.h */

/* A lot of wireless.h have kernel includes which should be protected by
   #ifdef __KERNEL__. They course include errors due to redefinitions of types.
   This prevents those kernel headers being included by Qtopia.
   */
#ifndef _LINUX_IF_H
#define _LINUX_IF_H
#endif
#ifndef _LINUX_SOCKET_H
#define _LINUX_SOCKET_H
#endif
#include <linux/wireless.h>

#include <KIcon>
// We need the Plasma Applet headers
#include <Plasma/Applet>
#include <Plasma/Svg>
#include <KDialog>
#include <QTimer>

#include <plasma/applet.h>
#include <plasma/dataengine.h>

#include "ui_config.h"

class QSizeF;

// Define our plasma Applet
class network_status : public Plasma::Applet
{
    Q_OBJECT
public:
    // Basic Create/Destroy
    network_status(QObject *parent, const QVariantList &args);
    ~network_status();

    // The paintInterface procedure paints the applet to the desktop
    void paintInterface(QPainter *painter,
                        const QStyleOptionGraphicsItem *option,
                        const QRect& contentsRect);
    void init();

public slots:
    void showConfigurationInterface();
    void updateData();

protected slots:
    void configAccepted();

private:
    int getLinkQuality();

    Ui::config ui;

    KDialog *m_dialog;
    QTimer *m_timer;

    QString m_ifName;
    void setIfName(QString ifName);

    bool m_isValid;
    void setIsValid(bool isValid);

    bool m_isWireless;
    void setIsWireless(bool isWireless);

    bool m_isActive;
    void setIsActive(bool isActive);

    int m_linkQuality;
    void setLinkQuality(int linkQuality);

    bool m_isDataChanged;
};

// This is the command that links your applet to the .desktop file
K_EXPORT_PLASMA_APPLET(network-status, network_status)
#endif

/* ex: set tabstop=4 shiftwidth=4 expandtab: */
